#include <NewSoftSerial.h>
#include <WString.h> 
#include <SdFat.h>
#include <SdFatUtil.h>

#define statusPin 2
#define speakerOut 3
#define logSwitch 4
#define Ekko_rxPin 5
#define GPS_rxPin 6
#define RUN_pin 7
#define Ekko_txPin 99 //dummy
#define GPS_txPin 99 //dummy

#define ON 1

#define BUFFERSIZE 200


Sd2Card card;
SdVolume volume;
SdFile root;
SdFile file;

// store error strings in flash to save RAM
#define error(s) error_P(PSTR(s))
void error_P(const char *str)
{
  PgmPrint("error: ");
  SerialPrintln_P(str);
  if (card.errorCode()) {
    PgmPrint("SD error: ");
    Serial.print(card.errorCode(), HEX);
    Serial.print(',');
    Serial.println(card.errorData(), HEX);
  }
  while(1);
}

void writeCRLF(SdFile &f)
{
  f.write((uint8_t *)"\r\n", 2);
}

void writeString(SdFile &f, char *str)
{
  uint8_t n;
  for (n = 0; str[n]; n++);
  f.write((uint8_t *)str, n);
}


int LogSjekk = 0;
NewSoftSerial EKKO(Ekko_rxPin, Ekko_txPin);
NewSoftSerial GPS(GPS_rxPin, GPS_txPin);

String Linje = String(BUFFERSIZE);

void setup()
{
  pinMode(statusPin, OUTPUT);
  pinMode(speakerOut, OUTPUT);
  pinMode(RUN_pin, OUTPUT);
  pinMode(logSwitch, INPUT);
  
  digitalWrite(statusPin, LOW);      // skru av LED
  digitalWrite(speakerOut, LOW);     // skrur av høytaler
  digitalWrite(RUN_pin, LOW);        // skrur av motor
  
  Serial.begin(9600);
  GPS.begin(4800);
  EKKO.begin(4800);  

  delay(2000); // Wait for system to stabilize
 
  if (!card.init()) error("card.init");
  if (!volume.init(card)) error("volume.init");
  if (!root.openRoot(volume)) error("openRoot");
  
  Header();
}

void loop()
{
  if (digitalRead(logSwitch) == ON)
    {
      GetDepth();
      skrivData();
      GetGPS_GGA();
      skrivData();
      GetGPS_RMC();
      skrivData();
      delay(2000); // Limit log entrys
      if (LogSjekk > 2) digitalWrite(RUN_pin, HIGH); //Turn on motor when log is verified
    } else {
      digitalWrite(RUN_pin, LOW);
      Serial.println("LOG -disabled-");
    };
};

void Header(void)
{
  Linje = "\n- New log -\n\n";
  skrivData();
};









